package com.kedacom.musicplayer;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v4.app.Fragment;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.ProgressBar;

public class PlayerFragment extends Fragment

{
    private playerControlInterface playerControlInterface;
    private final static String TAG = "PlayerFragment";
    private Button fakeButton;
    private ProgressBar progressBar;

    public interface playerControlInterface {
        public void onStartClick();

        public void onPauseClick();

        public void onNextClick();

        public void onPreviousClick();

        public void getProgressBar(ProgressBar progressBar);

        public Boolean getServiceState();

        public Integer getCurrentDuration();

        public Integer getCurrentPosition();
    }


    public PlayerFragment() {}

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        try {
            playerControlInterface = (playerControlInterface) getActivity();
        } catch (ClassCastException e) {
            throw new ClassCastException(getActivity().toString()
                    + " must implement playerControlInterface");
        }
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle bundle) {
        View v = inflater.inflate(R.layout.fragment_player, container, false);
        fakeButton = v.findViewById(R.id.fragment_player_fake_center_button);
        v.findViewById(R.id.fragment_player_next_button).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                playerControlInterface.onNextClick();
            }
        });
        v.findViewById(R.id.fragment_player_previous_button).setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                playerControlInterface.onPreviousClick();
            }
        });
        progressBar = v.findViewById(R.id.fragment_player_progress_bar);
        playerControlInterface.getProgressBar(progressBar);

        return v;
    }

    @Override
    public void onResume() {
        super.onResume();
        int[] location = new int[2];
        fakeButton.getLocationInWindow(location);
        Log.d(TAG, "onResume: x: " + location[0]);
        Log.d(TAG, "onResume: y: " + location[1]);
    }

    public void start() {
        playerControlInterface.onStartClick();
    }

    public void pause() {
        playerControlInterface.onPauseClick();
    }
}
